@@ -15,11 +15,11 @@
 #include <pika/async_mpi/trigger_mpi.hpp>
 #include <pika/concepts/concepts.hpp>
 #include <pika/debugging/print.hpp>
+#include <pika/execution/algorithms/continues_on.hpp>
 #include <pika/execution/algorithms/detail/helpers.hpp>
 #include <pika/execution/algorithms/detail/partial_algorithm.hpp>
+#include <pika/execution/algorithms/just.hpp>
 #include <pika/execution/algorithms/let_value.hpp>
-#include <pika/execution/algorithms/transfer.hpp>
-#include <pika/execution/algorithms/transfer_just.hpp>
 #include <pika/execution_base/any_sender.hpp>
 #include <pika/execution_base/receiver.hpp>
 #include <pika/execution_base/sender.hpp>
@@ -48,16 +48,15 @@ namespace pika::mpi::experimental {
             PIKA_DETAIL_DP(mpi_tran<5>, debug(str<>("transform_mpi_t"), "tag_fallback_invoke"));
 
             using execution::thread_priority;
+            using pika::execution::experimental::continues_on;
             using pika::execution::experimental::just;
             using pika::execution::experimental::let_value;
-            using pika::execution::experimental::transfer;
-            using pika::execution::experimental::transfer_just;
             using pika::execution::experimental::unique_any_sender;
 
             // get mpi completion mode settings
             auto mode = get_completion_mode();
-            bool inline_com = use_inline_completion(mode);
-            bool inline_req = use_inline_request(mode);
+            bool completions_inline = use_inline_completion(mode);
+            bool requests_inline = use_inline_request(mode);
 
 #ifdef PIKA_DEBUG
             // ----------------------------------------------------------
@@ -78,26 +77,27 @@ namespace pika::mpi::experimental {
                 execution::thread_priority::normal;
 
             auto completion_snd = [=](MPI_Request request) -> unique_any_sender<> {
-                if (!inline_com)
+                if (!completions_inline)    // not inline : a transfer is required
                 {
                     if (request == MPI_REQUEST_NULL)
                     {
-                        return transfer_just(default_pool_scheduler(p));
+                        return ex::schedule(default_pool_scheduler(p));
                     }
-                    return transfer_just(default_pool_scheduler(p), request) | trigger_mpi(mode);
+                    return just(request) | trigger_mpi(mode) |
+                        ex::continues_on(default_pool_scheduler(p));
                 }
                 if (request == MPI_REQUEST_NULL) { return just(); }
                 return just(request) | trigger_mpi(mode);
             };
 
-            if (inline_req)
+            if (requests_inline)
             {
                 return dispatch_mpi_sender<Sender, F>{PIKA_MOVE(sender), PIKA_FORWARD(F, f)} |
                     let_value(completion_snd);
             }
             else
             {
-                auto snd0 = PIKA_FORWARD(Sender, sender) | transfer(mpi_pool_scheduler(p));
+                auto snd0 = PIKA_FORWARD(Sender, sender) | continues_on(mpi_pool_scheduler(p));
                 return dispatch_mpi_sender<decltype(snd0), F>{PIKA_MOVE(snd0), PIKA_FORWARD(F, f)} |
                     let_value(completion_snd);
             }
