@@ -19,7 +19,6 @@
 #include <pika/debugging/print.hpp>
 #include <pika/execution/algorithms/detail/helpers.hpp>
 #include <pika/execution/algorithms/detail/partial_algorithm.hpp>
-#include <pika/execution/algorithms/transfer.hpp>
 #include <pika/execution_base/any_sender.hpp>
 #include <pika/execution_base/receiver.hpp>
 #include <pika/execution_base/sender.hpp>
@@ -58,8 +57,15 @@ namespace pika::mpi::experimental::detail {
         int completion_mode_flags_;
 
 #if defined(PIKA_HAVE_STDEXEC)
-        using completion_signatures = pika::execution::experimental::completion_signatures<
-            pika::execution::experimental::set_value_t()>;
+        template <typename...>
+        using no_value_completion = pika::execution::experimental::completion_signatures<>;
+        using completion_signatures =
+            pika::execution::experimental::transform_completion_signatures_of<std::decay_t<Sender>,
+                pika::execution::experimental::empty_env,
+                pika::execution::experimental::completion_signatures<
+                    pika::execution::experimental::set_value_t(),
+                    pika::execution::experimental::set_error_t(std::exception_ptr)>,
+                no_value_completion>;
 #else
         // -----------------------------------------------------------------
         // completion signatures
@@ -199,28 +205,9 @@ namespace pika::mpi::experimental::detail {
                                 PIKA_DETAIL_DP(mpi_tran<1>,
                                     debug(str<>("MPI_EXT_CONTINUE"), "register_mpix_continuation",
                                         ptr(r.op_state.request), ptr(r.op_state.request)));
-
-                                MPIX_Continue_cb_function* func = &mpix_callback<operation_state>;
-                                {
-                                    std::unique_lock l{r.op_state.mutex};
-                                    // make sure registration is done under lock to stop cond_var
-                                    // going out of scope before notification is sent
-                                    register_mpix_continuation(
-                                        &r.op_state.request, func, &r.op_state);
-                                    PIKA_DETAIL_DP(mpi_tran<1>,
-                                        debug(str<>("MPI_EXT_CONTINUE"), "waiting",
-                                            ptr(r.op_state.request)));
-                                    r.op_state.cond_var.wait(
-                                        l, [&]() { return r.op_state.completed; });
-                                }
-
-                                PIKA_DETAIL_DP(mpi_tran<1>,
-                                    debug(str<>("MPI_EXT_CONTINUE"), "woken",
-                                        ptr(r.op_state.request)));
-
-                                // call set_value/set_error depending on mpi return status
-                                set_value_error_helper(
-                                    r.op_state.status, PIKA_MOVE(r.op_state.receiver));
+                                MPIX_Continue_cb_function* func =
+                                    &mpix_callback_continuation<operation_state>;
+                                register_mpix_continuation(&r.op_state.request, func, &r.op_state);
                                 break;
                             }
                             default: PIKA_UNREACHABLE;
