@@ -254,7 +254,7 @@ void test_transfer_basic()
     });
     auto work2 = ex::then(std::move(work1),
         [=, &current_id]() { PIKA_TEST_EQ(current_id, std::this_thread::get_id()); });
-    auto transfer1 = ex::transfer(work2, sched);
+    auto transfer1 = ex::continues_on(work2, sched);
     auto work3 = ex::then(transfer1, [=, &current_id]() {
         std::thread::id new_id = std::this_thread::get_id();
         PIKA_TEST_NEQ(current_id, new_id);
@@ -263,7 +263,7 @@ void test_transfer_basic()
     });
     auto work4 = ex::then(
         work3, [=, &current_id]() { PIKA_TEST_EQ(current_id, std::this_thread::get_id()); });
-    auto transfer2 = ex::transfer(work4, sched);
+    auto transfer2 = ex::continues_on(work4, sched);
     auto work5 = ex::then(transfer2, [=, &current_id]() {
         std::thread::id new_id = std::this_thread::get_id();
         PIKA_TEST_NEQ(current_id, new_id);
@@ -290,7 +290,7 @@ void test_transfer_arguments()
         PIKA_TEST_EQ(current_id, std::this_thread::get_id());
         return x / 2.0;
     });
-    auto transfer1 = ex::transfer(work2, sched);
+    auto transfer1 = ex::continues_on(work2, sched);
     auto work3 = ex::then(transfer1, [=, &current_id](double x) {
         std::thread::id new_id = std::this_thread::get_id();
         PIKA_TEST_NEQ(current_id, new_id);
@@ -302,7 +302,7 @@ void test_transfer_arguments()
         PIKA_TEST_EQ(current_id, std::this_thread::get_id());
         return "result: " + std::to_string(x);
     });
-    auto transfer2 = ex::transfer(work4, sched);
+    auto transfer2 = ex::continues_on(work4, sched);
     auto work5 = ex::then(transfer2, [=, &current_id](std::string s) {
         std::thread::id new_id = std::this_thread::get_id();
         PIKA_TEST_NEQ(current_id, new_id);
@@ -332,7 +332,7 @@ void test_just_void()
         std::thread::id parent_id = std::this_thread::get_id();
 
         auto begin = ex::just();
-        auto transfer1 = ex::transfer(begin, ex::std_thread_scheduler{});
+        auto transfer1 = ex::continues_on(begin, ex::std_thread_scheduler{});
         auto work1 = ex::then(
             transfer1, [parent_id]() { PIKA_TEST_NEQ(parent_id, std::this_thread::get_id()); });
         tt::sync_wait(std::move(work1));
@@ -356,7 +356,7 @@ void test_just_one_arg()
         std::thread::id parent_id = std::this_thread::get_id();
 
         auto begin = ex::just(3);
-        auto transfer1 = ex::transfer(begin, ex::std_thread_scheduler{});
+        auto transfer1 = ex::continues_on(begin, ex::std_thread_scheduler{});
         auto work1 = ex::then(transfer1, [parent_id](int x) {
             PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
             PIKA_TEST_EQ(x, 3);
@@ -383,7 +383,7 @@ void test_just_two_args()
         std::thread::id parent_id = std::this_thread::get_id();
 
         auto begin = ex::just(3, std::string("hello"));
-        auto transfer1 = ex::transfer(begin, ex::std_thread_scheduler{});
+        auto transfer1 = ex::continues_on(begin, ex::std_thread_scheduler{});
         auto work1 = ex::then(transfer1, [parent_id](int x, std::string y) {
             PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
             PIKA_TEST_EQ(x, 3);
@@ -393,21 +393,21 @@ void test_just_two_args()
     }
 }
 
-void test_transfer_just_void()
+void test_just_continues_on_void()
 {
     std::thread::id parent_id = std::this_thread::get_id();
 
-    auto begin = ex::transfer_just(ex::std_thread_scheduler{});
+    auto begin = ex::just() | ex::continues_on(ex::std_thread_scheduler{});
     auto work1 =
         ex::then(begin, [parent_id]() { PIKA_TEST_NEQ(parent_id, std::this_thread::get_id()); });
     tt::sync_wait(std::move(work1));
 }
 
-void test_transfer_just_one_arg()
+void test_just_continues_on_one_arg()
 {
     std::thread::id parent_id = std::this_thread::get_id();
 
-    auto begin = ex::transfer_just(ex::std_thread_scheduler{}, 3);
+    auto begin = ex::just(3) | ex::continues_on(ex::std_thread_scheduler{});
     auto work1 = ex::then(begin, [parent_id](int x) {
         PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
         PIKA_TEST_EQ(x, 3);
@@ -415,11 +415,11 @@ void test_transfer_just_one_arg()
     tt::sync_wait(std::move(work1));
 }
 
-void test_transfer_just_two_args()
+void test_just_continues_on_two_args()
 {
     std::thread::id parent_id = std::this_thread::get_id();
 
-    auto begin = ex::transfer_just(ex::std_thread_scheduler{}, 3, std::string("hello"));
+    auto begin = ex::just(3, std::string("hello")) | ex::continues_on(ex::std_thread_scheduler{});
     auto work1 = ex::then(begin, [parent_id](int x, std::string y) {
         PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
         PIKA_TEST_EQ(x, 3);
@@ -649,17 +649,18 @@ void test_ensure_started()
     }
 
     {
-        auto s = ex::transfer_just(sched, 42) | ex::ensure_started();
+        auto s = ex::just(42) | ex::continues_on(sched) | ex::ensure_started();
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
 
     {
-        auto s = ex::transfer_just(sched, 42) | ex::ensure_started() | ex::transfer(sched);
+        auto s =
+            ex::just(42) | ex::continues_on(sched) | ex::ensure_started() | ex::continues_on(sched);
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
 
     {
-        auto s = ex::transfer_just(sched, 42) | ex::ensure_started() | ex::split();
+        auto s = ex::just(42) | ex::continues_on(sched) | ex::ensure_started() | ex::split();
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
@@ -760,11 +761,11 @@ void test_ensure_started_when_all()
             std::unique_lock l{mtx};
             cond.wait(l, [&]() { return started; });
         }
-        auto succ1 = s | ex::transfer(sched) | ex::then([&](int const& x) {
+        auto succ1 = s | ex::continues_on(sched) | ex::then([&](int const& x) {
             ++successor_task_calls;
             return x + 1;
         });
-        auto succ2 = s | ex::transfer(sched) | ex::then([&](int const& x) {
+        auto succ2 = s | ex::continues_on(sched) | ex::then([&](int const& x) {
             ++successor_task_calls;
             return x + 2;
         });
@@ -785,17 +786,17 @@ void test_split()
     }
 
     {
-        auto s = ex::transfer_just(sched, 42) | ex::split();
+        auto s = ex::just(42) | ex::continues_on(sched) | ex::split();
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
 
     {
-        auto s = ex::transfer_just(sched, 42) | ex::split() | ex::transfer(sched);
+        auto s = ex::just(42) | ex::continues_on(sched) | ex::split() | ex::continues_on(sched);
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
 
     {
-        auto s = ex::transfer_just(sched, 42) | ex::split();
+        auto s = ex::just(42) | ex::continues_on(sched) | ex::split();
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
@@ -855,11 +856,11 @@ void test_split_when_all()
             ++first_task_calls;
             return 3;
         }) | ex::split();
-        auto succ1 = s | ex::transfer(sched) | ex::then([&](int const& x) {
+        auto succ1 = s | ex::continues_on(sched) | ex::then([&](int const& x) {
             ++successor_task_calls;
             return x + 1;
         });
-        auto succ2 = s | ex::transfer(sched) | ex::then([&](int const& x) {
+        auto succ2 = s | ex::continues_on(sched) | ex::then([&](int const& x) {
             ++successor_task_calls;
             return x + 2;
         });
@@ -883,54 +884,57 @@ void test_let_value()
     }
 
     {
-        auto result = tt::sync_wait(
-            ex::schedule(sched) | ex::let_value([=]() { return ex::transfer_just(sched, 42); }));
+        auto result = tt::sync_wait(ex::schedule(sched) |
+            ex::let_value([=]() { return ex::just(42) | ex::continues_on(sched); }));
         PIKA_TEST_EQ(result, 42);
     }
 
     {
         auto result = tt::sync_wait(
-            ex::just() | ex::let_value([=]() { return ex::transfer_just(sched, 42); }));
+            ex::just() | ex::let_value([=]() { return ex::just(42) | ex::continues_on(sched); }));
         PIKA_TEST_EQ(result, 42);
     }
 
     // int predecessor, value ignored
     {
-        auto result = tt::sync_wait(
-            ex::transfer_just(sched, 43) | ex::let_value([](int&) { return ex::just(42); }));
+        auto result = tt::sync_wait(ex::just(43) | ex::continues_on(sched) |
+            ex::let_value([](int&) { return ex::just(42); }));
         PIKA_TEST_EQ(result, 42);
     }
 
     {
-        auto result = tt::sync_wait(ex::transfer_just(sched, 43) |
-            ex::let_value([=](int&) { return ex::transfer_just(sched, 42); }));
+        auto result = tt::sync_wait(ex::just(43) | ex::continues_on(sched) |
+            ex::let_value([=](int&) { return ex::just(42) | ex::continues_on(sched); }));
         PIKA_TEST_EQ(result, 42);
     }
 
     {
-        auto result = tt::sync_wait(
-            ex::just(43) | ex::let_value([=](int&) { return ex::transfer_just(sched, 42); }));
+        auto result = tt::sync_wait(ex::just(43) |
+            ex::let_value([=](int&) { return ex::just(42) | ex::continues_on(sched); }));
         PIKA_TEST_EQ(result, 42);
     }
 
     // int predecessor, value used
     {
-        auto result = tt::sync_wait(ex::transfer_just(sched, 43) | ex::let_value([](int& x) {
-            return ex::just(42) | ex::then([&](int y) { return x + y; });
-        }));
+        auto result =
+            tt::sync_wait(ex::just(43) | ex::continues_on(sched) | ex::let_value([](int& x) {
+                return ex::just(42) | ex::then([&](int y) { return x + y; });
+            }));
         PIKA_TEST_EQ(result, 85);
     }
 
     {
-        auto result = tt::sync_wait(ex::transfer_just(sched, 43) | ex::let_value([=](int& x) {
-            return ex::transfer_just(sched, 42) | ex::then([&](int y) { return x + y; });
-        }));
+        auto result =
+            tt::sync_wait(ex::just(43) | ex::continues_on(sched) | ex::let_value([=](int& x) {
+                return ex::just(42) | ex::continues_on(sched) |
+                    ex::then([&](int y) { return x + y; });
+            }));
         PIKA_TEST_EQ(result, 85);
     }
 
     {
         auto result = tt::sync_wait(ex::just(43) | ex::let_value([=](int& x) {
-            return ex::transfer_just(sched, 42) | ex::then([&](int y) { return x + y; });
+            return ex::just(42) | ex::continues_on(sched) | ex::then([&](int y) { return x + y; });
         }));
         PIKA_TEST_EQ(result, 85);
     }
@@ -941,7 +945,7 @@ void test_let_value()
 
         try
         {
-            tt::sync_wait(ex::transfer_just(sched, 43) | ex::then([](int) -> int {
+            tt::sync_wait(ex::just(43) | ex::continues_on(sched) | ex::then([](int) -> int {
                 throw std::runtime_error("error");
             }) | ex::let_value([](int&) {
                 PIKA_TEST(false);
@@ -996,7 +1000,7 @@ void test_let_error()
             ex::let_error([=, &called](std::exception_ptr& ep) {
                 called = true;
                 check_exception_ptr_message(ep, "error");
-                return ex::transfer_just(sched);
+                return ex::schedule(sched);
             }));
         PIKA_TEST(called);
     }
@@ -1007,7 +1011,7 @@ void test_let_error()
             ex::let_error([=, &called](std::exception_ptr& ep) {
                 called = true;
                 check_exception_ptr_message(ep, "error");
-                return ex::transfer_just(sched);
+                return ex::schedule(sched);
             }));
         PIKA_TEST(called);
     }
@@ -1028,7 +1032,7 @@ void test_let_error()
             throw std::runtime_error("error");
         }) | ex::let_error([=](std::exception_ptr& ep) {
             check_exception_ptr_message(ep, "error");
-            return ex::transfer_just(sched, 42);
+            return ex::just(42) | ex::continues_on(sched);
         }));
         PIKA_TEST_EQ(result, 42);
     }
@@ -1038,15 +1042,15 @@ void test_let_error()
             throw std::runtime_error("error");
         }) | ex::let_error([=](std::exception_ptr& ep) {
             check_exception_ptr_message(ep, "error");
-            return ex::transfer_just(sched, 42);
+            return ex::just(42) | ex::continues_on(sched);
         }));
         PIKA_TEST_EQ(result, 42);
     }
 
     // predecessor doesn't throw, let sender is ignored
     {
-        auto result =
-            tt::sync_wait(ex::transfer_just(sched, 42) | ex::let_error([](std::exception_ptr) {
+        auto result = tt::sync_wait(
+            ex::just(42) | ex::continues_on(sched) | ex::let_error([](std::exception_ptr) {
                 PIKA_TEST(false);
                 return ex::just(43);
             }));
@@ -1054,10 +1058,10 @@ void test_let_error()
     }
 
     {
-        auto result =
-            tt::sync_wait(ex::transfer_just(sched, 42) | ex::let_error([=](std::exception_ptr) {
+        auto result = tt::sync_wait(
+            ex::just(42) | ex::continues_on(sched) | ex::let_error([=](std::exception_ptr) {
                 PIKA_TEST(false);
-                return ex::transfer_just(sched, 43);
+                return ex::just(43) | ex::continues_on(sched);
             }));
         PIKA_TEST_EQ(result, 42);
     }
@@ -1065,7 +1069,7 @@ void test_let_error()
     {
         auto result = tt::sync_wait(ex::just(42) | ex::let_error([=](std::exception_ptr) {
             PIKA_TEST(false);
-            return ex::transfer_just(sched, 43);
+            return ex::just(43) | ex::continues_on(sched);
         }));
         PIKA_TEST_EQ(result, 42);
     }
@@ -1136,11 +1140,12 @@ void test_bulk()
         std::vector<int> v(n, -1);
         std::thread::id parent_id = std::this_thread::get_id();
 
-        auto v_out = tt::sync_wait(ex::transfer_just(ex::std_thread_scheduler{}, std::move(v)) |
-            ex::bulk(n, [&parent_id](int i, std::vector<int>& v) {
-                v[i] = i;
-                PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
-            }));
+        auto v_out =
+            tt::sync_wait(ex::just(std::move(v)) | ex::continues_on(ex::std_thread_scheduler{}) |
+                ex::bulk(n, [&parent_id](int i, std::vector<int>& v) {
+                    v[i] = i;
+                    PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
+                }));
 
         for (int i = 0; i < n; ++i) { PIKA_TEST_EQ(v_out[i], i); }
     }
@@ -1173,7 +1178,7 @@ void test_bulk()
 
         try
         {
-            tt::sync_wait(ex::transfer_just(ex::std_thread_scheduler{}) | ex::bulk(n, [&v](int i) {
+            tt::sync_wait(ex::schedule(ex::std_thread_scheduler{}) | ex::bulk(n, [&v](int i) {
                 if (i == i_fail) { throw std::runtime_error("error"); }
                 v[i] = i;
             }));
@@ -1216,7 +1221,7 @@ void test_completion_scheduler()
     }
 
     {
-        auto sender = ex::transfer_just(ex::std_thread_scheduler{}, 42);
+        auto sender = ex::just(42) | ex::continues_on(ex::std_thread_scheduler{});
         auto completion_scheduler =
             ex::get_completion_scheduler<ex::set_value_t>(ex::get_env(sender));
         static_assert(
@@ -1234,8 +1239,8 @@ void test_completion_scheduler()
     }
 
     {
-        auto sender = ex::then(
-            ex::bulk(ex::transfer_just(ex::std_thread_scheduler{}, 42), 10, [](int, int) {}),
+        auto sender = ex::then(ex::bulk(ex::just(42) | ex::continues_on(ex::std_thread_scheduler{}),
+                                   10, [](int, int) {}),
             [](int) {});
         auto completion_scheduler =
             ex::get_completion_scheduler<ex::set_value_t>(ex::get_env(sender));
@@ -1245,8 +1250,8 @@ void test_completion_scheduler()
     }
 
     {
-        auto sender = ex::bulk(
-            ex::then(ex::transfer_just(ex::std_thread_scheduler{}, 42), [](int x) { return x; }),
+        auto sender = ex::bulk(ex::then(ex::just(42) | ex::continues_on(ex::std_thread_scheduler{}),
+                                   [](int x) { return x; }),
             10, [](int, int) {});
         auto completion_scheduler =
             ex::get_completion_scheduler<ex::set_value_t>(ex::get_env(sender));
@@ -1276,9 +1281,9 @@ int main()
     test_just_void();
     test_just_one_arg();
     test_just_two_args();
-    test_transfer_just_void();
-    test_transfer_just_one_arg();
-    test_transfer_just_two_args();
+    test_just_continues_on_void();
+    test_just_continues_on_one_arg();
+    test_just_continues_on_two_args();
     test_when_all();
     test_when_all_vector();
     test_ensure_started();
