@@ -158,9 +158,10 @@ namespace pika::util::detail {
 namespace pika::detail {
 #if defined(PIKA_HAVE_THREAD_DESCRIPTION)
     template <typename F, typename... Ts>
-    struct get_function_address<util::detail::bound_front<F, Ts...>>
+    struct get_function_address<pika::util::detail::bound_front<F, Ts...>>
     {
-        static constexpr std::size_t call(util::detail::bound_front<F, Ts...> const& f) noexcept
+        static constexpr std::size_t call(
+            pika::util::detail::bound_front<F, Ts...> const& f) noexcept
         {
             return f.get_function_address();
         }
@@ -168,9 +169,10 @@ namespace pika::detail {
 
     ///////////////////////////////////////////////////////////////////////////
     template <typename F, typename... Ts>
-    struct get_function_annotation<util::detail::bound_front<F, Ts...>>
+    struct get_function_annotation<pika::util::detail::bound_front<F, Ts...>>
     {
-        static constexpr char const* call(util::detail::bound_front<F, Ts...> const& f) noexcept
+        static constexpr char const* call(
+            pika::util::detail::bound_front<F, Ts...> const& f) noexcept
         {
             return f.get_function_annotation();
         }
@@ -178,9 +180,10 @@ namespace pika::detail {
 
 # if PIKA_HAVE_ITTNOTIFY != 0 && !defined(PIKA_HAVE_APEX)
     template <typename F, typename... Ts>
-    struct get_function_annotation_itt<util::detail::bound_front<F, Ts...>>
+    struct get_function_annotation_itt<pika::util::detail::bound_front<F, Ts...>>
     {
-        static util::itt::string_handle call(util::detail::bound_front<F, Ts...> const& f) noexcept
+        static util::itt::string_handle call(
+            pika::util::detail::bound_front<F, Ts...> const& f) noexcept
         {
             return f.get_function_annotation_itt();
         }
