@@ -15,6 +15,7 @@
 #include <pika/testing.hpp>
 
 #include <chrono>
+#include <cstdlib>
 #include <functional>
 #include <mutex>
 #include <thread>
@@ -57,7 +58,8 @@ int pika_main()
         PIKA_TEST(false);
     }
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[])
